@@ -1,8 +1,10 @@
 mod builder;
 mod dev;
+mod durable_objects;
 mod environment;
 mod kv_namespace;
 mod manifest;
+pub mod migrations;
 mod route;
 mod site;
 mod target;
@@ -10,6 +12,7 @@ mod target_type;
 mod triggers;
 
 pub use builder::{Builder, ModuleRule, UploadFormat};
+pub use durable_objects::{DurableObjects, DurableObjectsClass};
 pub use environment::Environment;
 pub use kv_namespace::{ConfigKvNamespace, KvNamespace};
 pub use manifest::Manifest;
@@ -18,6 +21,7 @@ pub use site::Site;
 pub use target::Target;
 pub use target_type::TargetType;
 
+use anyhow::anyhow;
 use serde::{Deserialize, Serialize};
 use std::str::FromStr;
 
@@ -29,13 +33,15 @@ pub enum UsageModel {
 }
 
 impl FromStr for UsageModel {
-    type Err = failure::Error;
+    type Err = anyhow::Error;
 
     fn from_str(s: &str) -> Result<Self, Self::Err> {
         match s {
             "bundled" => Ok(UsageModel::Bundled),
             "unbound" => Ok(UsageModel::Unbound),
-            _ => failure::bail!("Invalid usage model; must be either \"bundled\" or \"unbound\""),
+            _ => Err(anyhow!(
+                "Invalid usage model; must be either \"bundled\" or \"unbound\""
+            )),
         }
     }
 }
