@@ -1,8 +1,10 @@
-use super::builder::Builder;
+use super::durable_objects::DurableObjects;
 use super::kv_namespace::KvNamespace;
+use super::manifest::LazyAccountId;
 use super::site::Site;
 use super::target_type::TargetType;
 use super::UsageModel;
+use super::{builder::Builder, migrations::Migrations};
 
 use std::collections::HashMap;
 use std::env;
@@ -11,8 +13,10 @@ use std::path::PathBuf;
 
 #[derive(Clone, Debug, Default)]
 pub struct Target {
-    pub account_id: String,
+    pub account_id: LazyAccountId,
     pub kv_namespaces: Vec<KvNamespace>,
+    pub durable_objects: Option<DurableObjects>,
+    pub migrations: Option<Migrations>,
     pub name: String,
     pub target_type: TargetType,
     pub webpack_config: Option<String>,
